@@ -1,9 +1,9 @@
 #include "TextSet.hpp"
 
 #include "glgui.hpp"
+#include "R.h"
 #ifdef HAVE_FREETYPE
 #include "Viewpoint.hpp"
-#include "R.h"
 #include <map>
 #endif
 //////////////////////////////////////////////////////////////////////////////
@@ -58,6 +58,7 @@ void TextSet::render(RenderContext* renderContext)
 
 void TextSet::drawBegin(RenderContext* renderContext) 
 {
+  Shape::drawBegin(renderContext);
   material.beginUse(renderContext);
 }
 
@@ -78,9 +79,11 @@ void TextSet::drawElement(RenderContext* renderContext, int index)
       }
     }
   }
+  SAVEGLERROR;
 }
 
 void TextSet::drawEnd(RenderContext* renderContext)
 {
   material.endUse(renderContext);
+  Shape::drawEnd(renderContext);
 }
